%%%%%%%%%%%%%%%%%
% $Id$
\documentclass{article}

\usepackage{malayalam} % defaults to rachana

\begin{document}

\centerline{<m>\Huge\bf shESaM skrInil</m>}

\medskip

\centerline{<m>\large (akbaR kakkaTTil)</m>}
\medskip
\centerline{<m>\small (1996 AgasRR 4 n~AyaRAzhcatte mAt.rbhUmi
vArAntappatippil prasiddhIkariccat)</m>}
\bigskip


<m>
lORi Draiv ceytukoNT mOhanlAl. abhimukhamAyi jIppil
pOlIs AppIsaR. mOhanlAl lORi jIppiniTT iTikkunnu.
jIpp pinnOkkaM pOyi maRiyukayAN<<+. pOlIsAppIsaR
cATi rakSappeTunnu. lAl an"n"Ere piTikUTi akhilEntyA
iTi.

janaM shvAsamaTakkippiTicc kANukayAN<<+. kaiyaTi
haRSAravattilO haRSAravaM kaiyaTiyilO mun"n"unnat?

AppIsaR tiriccu tallAn tuTan"n"iyirikkunnu.

``lAlin<<+ enten"kiluM paRRuvO?''

oru ceRuppakkAran toTTaTuttirikkunna can"n"Atiye tONTi
valicc cOdikkunnu. paribhrAntikoNT shabdaM iTaRiyiTaRi
cinni vIzhukayAyirunnu. nen~c pinnilEkk valicc kaNNuM
vAyuM paramAvadhi tuRanna nilayil nOTTaM skrInilEkku tanne.

kUTTukAranuM itE avasthayilAyirunnu.

ayALuM iTaRccayuLLa shabdattil, oru iLaM karaccilinRe
maTTil paRayukayAyi.

``n~AnuM ninneppOle AdyAyiTTallE kANunnat. enikkaRiyO?''

lAlin<<+ potire tallu koLLunnuNT.

``tiriccaTiyeTA mOnE.... n~an"n"aLe viSamippikkallE.''
orAL viLiccu paRan~n~u.

``gusti lAlETTane paThippikkallE....''
maRRorALuTe vaka.

appOzhEkkuM lAl nalla fOmilAyi. pOlIsAppIsaR lAlinRe
iTi ozhivAkkAn baddhappeTukayAN<<+.

peTTenn tiyERRaRil ninn oru kANi eNIRRuninn lAline
nOkki oRRa alaRcca: ``niRtteTA aTi!''

A alaRccayil lAluM naTun"n"ippOyi. lAl aTi niRtti
prEkSakaruTe nEre kaNNayaccu. kANi nilkkunnat
lAlin<<+ kANAM. pOlIsAppIsaRuM iTiyERRuvINa
kiTappil ninn tala pokki kANiye nOkkunnu.

``niRtteTA!'' kANi vINTuM vINTuM paRayukayAyirunnu.

``entA AshAnE it? it sinimayallE?'' lAl kitaccukoNT,
ennAl oru ciri viTaRtti cOdiccu.

``sinimyAnn vecc in"n"anENTO oru tOnnyAsaM. oru
pOlIsudyOgasthane in"n"ane tallAn pATuNTO. tAn
sinima tuTan"n"iyatu mutal kaLikkunnat pOlIsukArOTANallO?''
kANi vikArabharitanAvukayAN<<+.

``AshAne manassilAyillallO. AshAn Eten"kiluM
pOlIsukAranRe makanANO?''

`lAl sRRaili'luLLa A cOdyaM kANikku rasiccillennu tIRcca.

``pOlIsukAranRe makanalla, acchanANenn kUTTikkO.''
kANi paRan~n~u.

pakSE, lAl prakOpanamuNTAkkAn ninnilla. lAl saumyamAyi
cOdiccu. ``alla, entA prashnaM?''

``prashnaM palatAN<<+,'' kANi paRayAn tuTan"n"i:
``onnAmat, tannEkkAL taTimiTukkuM karuttumuLLa orALe
tAn aTiccuvIzhttunna oru sthiraM lainuNTallO. at
tIreyan"n" vishvasikkAnAvunnilla. pattuM anpatuM
pEre onniccu nirappAkkunnat kANunpOL karan~n~upOkunnu.
it valla tamiLnATTiluM koLLAM. kEraLattil vENTa.''

lAl entO maRupaTi paRayAn tuTan"n"iyatAN<<+.
atiniTayil pOlIsAppIsaR eNIRR poTitaTTi, kANiyOToru
kAcc: ``it tamiLnATallen"kiluM, aviTeninn pirin~n~u
pOnna nATallE. mASE, it n~an"n"aLuTe tozhilAN<<+.
dayavAyi tozhil ceytu jIvikkAnanuvadikkU.''

``tozhil! fU!...'' kANi kUTutal cUTAvukayAN<<+.
``I caLL cekkanRe tallu koLLAn ninnu koTukkalANOTO
tozhil... pOyi valla cumaTumeTutt jIvikkeTO.''

``suh.rttE, tAn"kaL peTTennin"n"ane
prakOpitanAyatentAN<<+'', lAl iTapeTTu.

``pOlIsukAR in"n"ane nirantaraM tallukoLLAn Etu
nATTilATO ninnu tarika? I AppIsaRuTe kARyaM
tanneyeTukk. ninRe iTi vAn"n"An mAtraM
yUNifOmiTT iyALin"n"ane oRRakk naTakkukayANO?
oru saMgati avatarippikkunpOL atiloru yukti
vENTE?''

``n~an"n"aL niraparAdhikaLAN<<+. tirakkathAk.rtt
ezhutivaykkunnat saMvidhAyakan paRayunnatanusaricc
ceyyukamAtramAN<<+ n~an"n"aL.''

lAl kANiye anunayippikkAnuLLa shramattilAN<<+.
pakSE, kANi atuM lAline aTikkAnuLLa vaTiyAkki.

``ellAM tirakkathAk.rttinRe bhAvanayil ninnu
varunnatu tanne, aRiyAM. TenSan muzhuvan
an"n"ERkkallE. nin"n"aLkk samayatt mEkkappumiTT
vannu tirin~n~Al pOrE? entu sukhaM! kayyaTiyuM
haRSAravavuM paNavuM nin"n"aLkk. an"n"Ere
ArOR{}kkunnu?''

``n~AnORttallO...tAn"kaL bahumAnikkunna
addEhamezhutiyatAN<<+ n~an"n"aL ceyyunnat.''

``addEhaM ezhutunnatentuM n~an"n"aL
aMgIkarikkumennatinaRtthamilla.''

``en"kil vishadIkaraNaM an"n"ErOTu tanne cOdikk.
viLikk.''

tiyERRaRil entO asukhakaramAyat saMbhavikkunnuvenn
kaNT OppaRERRaR puRattu vannirunnu. OTiccukoNTirunna
sinima peTTennu nilkkukayuM lAluM maRRuM kANikaLuTe
pratikaraNan"n"aLkk maRupaTi paRayAn tuTan"n"ukayuM
ceytatOTe ayAL skrIninaTuttettiyirunnu.

``I filiM n~An palavaTTaM kaNTatAN<<+. itil oriTattuM
tirakkathAk.rttinRe poTipOlumilla.'' OppaRERRaR
iTapeTTu paRan~n~u. lAl ciriccu.

``ini entu ceyyuM?'' lAl kANiye nOkki cOdiccu.

``I rItiyilAN<<+ sinima munpOTTu pOkunnaten"kil,
dA aviTe eksiRR kANunnillE, iRan"n"i poykkOTA...!''
kANi alaRi.

poTunnane lAlinRe maTTu mARi.

``atu tAn mAtraM paRan~n~Al pOrallO...iviTeyirikkunna
mAnyaprEkSakaruTe abhiprAyamaRiyaNamallO.''

maRRu kANikaL ituvarEyuM kSamiccirikkukayAyirunnu.
iTaykk rasakkayaR muRin~n~atil avaR asahiSNukkaLAyirunnu.

``lAlETTA, nin"n"aL kaLikk, n~an"n"aL oRRakkeTTAyi pinniluNT...''
avarilorAL viLiccupaRan~n~u.

``entu pinniluNTenneTO...nIyokkeyANivare vazhi teRRikkunnat.''
kANi kSObhattOTe paRan~n~u. ayALkk dESyaM koNT viRaykkunnuNT.

``celaykkANT nikk nAyinRe mOnE...kuRE nEramAyi n~an"n"aLitu
sahikkunnu. lAlETTan ninnOT mAnyamAyi saMsArikkunnatu kaNT
n~an"n"aL aTan"n"iyirunnatA...'' vERorAL AvEshapUR\mbox{}vaM
tuTaRnnu. ``nammuTeyokke pen"n"ammAre oru pOlIsukAran
upadraviccAl<<+ ceRuviralanakkAn paRROTO nammaLil palaRkkuM?
lAlETTan atu ceyyunpaM santOSikkvallE vENTat?
pOlIsukArane iTicc lavalAkk lAlETTA...ivanReyoru yukti...''

kANi vINTuM entO paRayAn tuTan"n"unpOzhEkk ArO kayaRi
ayALuTe SaRTTil piTiccu. orALkkUTTaM tanne ayALe potin~n~u.

``ayyO, enne tallallE...'' kANi nilaviLiccu.

AruM atu cevikkoNTilla. OrOruttaruM avaravaRkkAvunna vidhattil
kANiye kaikARyaM ceytu.

``onnuM ceyyallE, onnuM ceyyallE...'' lAl viLiccu
paRan~n~en"kiluM at bahaLan"n"aLkkiTayil mun"n"ippOyi.

OppaRERRaR vINTuM paTaM OTikkAn kAbinilEkk pOkuM
munpu tanne sthalattettiya pOlIsukAR kANiye veLLavastraM
koNT putappicc ODiRRORiyattil ninn nIkkaM ceytu.

skrInil lAluM AppIsaRuM tammiluLLa iTi tuTarukayAyi.

</m>

\end{document}


