%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Selected Articles from
% `Sanjayan Vol.1'
% Published by Mathrubhoomi
%
% Alex. A.J
% $Id$
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\documentclass[a4paper]{report}

\usepackage[rachana]{malayalam}

%\addtolength{\hoffset}{-.6in}
%\addtolength{\textwidth}{1in}
%\addtolength{\topmargin}{-.7in}
%\addtolength{\textheight}{1.5in}

\pagestyle{headings}

\begin{document}

\title{<m>\Huge\bf san~jayan</m>}
\author{<m>teran~n~eTutta lEkhanan"n"aL</m>}
\date{}
\maketitle

\tableofcontents

<m>

\chapter{puttan shailikaL}

kUTTarE, nin"n"aLAren"kiluM oru vivaramaRin~n~uvO? IyiTeyaayi
nammuTe malayaaLa gadyattil oru putiya shaili kaTannukUTITTuNT.
I shailiyil raNTaaLukaL ezhutiya raNTu pustakan"n"aL vaayikkuvaanuLLa
mahaabhaagyaM enikkuNTaayi. pustakan"n"aLuTe pEru paRan~n~iTTaavashyamilla;
granthakaRttaakkaLuTe pEr n~aan pOlIs sRRESanil veccukUTi paRayukayilla.
aviTevaccu paRayaatta kaaRyamillennaaNu potujanaabhipraayaM.
hEDinRe kaNNu kaaNunpOL ceyyaatta kuRRaM kUTi sammaticc,
santOSasamEtaM jElil pOkaamennu tOnnippOkumatrE.

atirikkaTTe. putiya shailiyekkuRiccaaNallO nammaL paRayunnat.
prastuta shailikku cila vishESan"n"aLokkeyuNT. at cilaRkku piTikkuM,
cilaRkku piTikkilla. atu pan~casaarayaaNennu paRayunnavaruNTen"kil,
atine kaan~n~irakkaayaayi karutunnavarumuNT. kavikaLkkumaatramE
atezhutikkUTu; paNDitanmaaRkkumaatramE atu manassilaavukayuLLU.
gadyaM pOleyaaN<<+ atezhutappeTunnaten"kiluM padyaM pOleyaaN<<+
atinRe svabhaavaM. atil upamayuM ulprEkSayuM atrayuNTaayirikkuM.
atu muzhuvan viraamacihnamayamaaN<<+. OrO vaakkumaatraM aTan"n"iya
vaacakan"n"aL, tIvaNTiyuTe en~cin taniccu pOkunnatupOle,
atilkkUTi pOkunnatu kANAM. cila vaacakan"n"aL, shrIraaman
kaaccikkaLan~n~a siddhasamaajasanyaasiyeppOle, talakIzhAyi
tUn"n"inilkkunnatu kaaNaaM. cila cillaRakkavikaLuTe
prasaMgan"n"aLiluM, cila patran"n"aLile lEkhana---(%
paNDitanmaaruTe neRRicuLi kaNTiTT) lEkhanan"n"aLiluM
I shaili pratyakSappeTaaRuNT.

san~jayann I gadyaM kaNTiTT atinOT oru prEmaM vannupOyi.
atinRe maadhuRyaM atrayuNT. mUnnudivasaM raatri uRakkozhin~n~u
shramiccatinRe falamaayi I putiya rItiyil san~jayan kuRe
upanyaasan"n"aL ezhutiyiTTuNT. I vazhiyil vaLare
kaTannupOyiTTuLLa gurukkanmaaruTe ``leval'' ettITTillen"kiluM,
atinRe oru ``pOkk'' kaaNikkuvaan maatramokke saad.rshyaM
ivaykkuNTenn, avataarika ezhutittaraan vicaarikkunna
aaLOT, viTTupOkaate ezhutuvaan praivaRRaayi apEkSikkunnu.

\bigskip

onnaamatte upanyaasaM daivattekkuRiccaaN<<+. in"n"ane
tuTan"n"unnu:---

{\it ``daivaM. saccidaanandasvarUpaM. akhaNDaM.
anantaM. shivOhaM. svastyastu. catukuppa.

manuSyan onnine---oraaLe---AraadhikkunnuNT. Are? daivattine.
entinn? avaRkku vERe paNiyonnumillaan~n~iTT.

kuTTiccaattan, guLikan, kuNTURkkOTT vaaNavan, munisippaal
kammISaNaR, bhairavan---ivaruM daivan"n"aL tanne.
pakSE avaruM daivavuM!!!--nakSatran"n"aLuM candranuM--%
kauNsilaRmaaruM ceyaRmaanuM--nirIshvaranmaaruM saRdaaR---%
(vENTa; n~aan paRayunnilla; allen"kilttanne addEhaM
san~jayanRe nEre kaaraNamillaate paribhaviccirikkunnu.)

daivaM bhaktivIciyuTe samudramaaN<<+; mOkSaagniyuTe
pukayaaN<<+, upaniSalppaalile veNNayaaN<<+,
vEdaantyamadyattinRe lahariyaaN<<+, jeMbiskaRRaaN<<+,
maramurin"n"ayaaN<<+, kutiravaTTamaaN<<+.''
}


itineppaRRi nin"n"aL entu vicaarikkunnu? itinRe guNagaNan"n"aL
nin"n"aL manassirutti `nOTTu' ceyyaNaM. cila vaacakan"n"aL,
oroRRa vaakkOTukUTi, katinaveTipOle, gaMbhIramAyi muzhan"n"i
avasaanikkunnatu kaNTuvO? maRRu cilat, kOzhappaTakaM pOle,
aRddhaviraaman"n"aLOTukUTi poTTitteRikkunnat kETTuvO?
itile upamakaL oru mahaakavikkallaate ezhutuvaan kazhiyumO?
iviTe gadyamezhutiiTTaaN<<+ mahaakaviyenna sthaanaM
sanpaadikkaan pOkunnat. sUkSiccOLin!

\bigskip

eniyorupanyaasamuNT, kavitayeppaRRi. atuM oruvidhaM
paassaakkaavunnataaN<<+.

{\it
``oru pon{}vINayuNT. oru svaatantryamuraLiyuNT.
oru DabLRID haaRmmONiyamuNT. oru pOlIs visiluNT. entaaNat? kavita.
Aru paRayunnu? n~aan.

atilkkUTi niRggaLikkunnatO? svaatantryamadhu, Anandadhaara,
samatvaM, saubhaatraM, sODa, lemaneD, amarakOshaM, pan~catantraM,
bObilipuraaNaM.

itonnaaN<<+ bhuumiye svaRggamaakkunnat. it vaTakkuMkUR
raajaraajavaRmma raajaavinnillaattatuM, uLLUrin<<+
uLLatumaakunnu. itillen"kil nakSatraM prakaashikkukayilla;
ilakTrik laiRR kattukayilla; mOTTORkaaR sRRaaRTTaavukayilla;
n~aanezhutukayilla; patraadhipaR svIkarikkukayilla;
nin"n"aL vaayikkukayilla.

kavita! haa! hU! kavita!!''


}

kavitayeppaRRi onnantaramoraRiv vaayanakkaaRkk itil{}ninnu
kiTTiyallO. ataaN<<+ I shailiyuTe guNaM. vaayiccaal pinne
A viSayattekkuRicc ARkkuM oru saMshayavuM uNTaavukayilla.
maayaatta citran"n"aLuMkoNT pulivaalu piTiccu kiTakkunna
nin"n"aLuTe saahityadaasanOT samayamuLLappOL itokke onnu
vaayiccunOkki oru ``aprIsESyan'' ezhutuvaan paRayaNaM.

\bigskip

eni n~aan orudaaharaNaM koTukkunnat talakIzhaay nil{}kkunna
rItikkaaN<<+. I rOgaM adhikavuM praasaMgikanmaareyaaN<<+
baadhiccukaaNunnat; cilappOL it samayaM pOraatta cila
patralEkhakanmaaRkkuM piTiccukaaNaaRuNT. it orutaraM
vaatagOSTiyaaNenn paRayunnavaruNT. kaaTaacciRa kaNNan
vaidyaravaRkaLuTe abhipraayaM aRin~n~iTTilla. cOdikkaNaM.
I shailiyiluM n~aan cilatezhutiyiTTuNT. ippOzhatte
tiran~n~eTuppukaLeppaRRi oru vOTTupiTiyanRe vOTTaRmaarOTuLLa
prasaMgamaaN<<+ taazhe cERkkunnat:

{\it
\noindent ``mahatikaLE, mahaanmaarE,

enikkaRiyaaM, nin"n"aLil adhikapEruM iviTe vannu nilkkunnat
nin"n"aLkku maRRu yaatonnuM ceyyuvaanillaattatukoNTaaNenn.
at kETT muSiyarut nin"n"aL. ARkken"kiluM koTukkaaM vOTT.
AlOciccu vENaM pakSE, upayOgikkuvaan A adhikaaraM.
n~aan paRayunnu, nin"n"aL vOTT raajashrI paataaLaraajaavinnu
koTukkaNamenn. ataaN<<+ oru maaRggaM, nanmakkuLLa. paRayaamO
ennOT dhaiRyasamEtaM nin"n"aL an"n"ane ceyyumenn?''

}

it mati. taLaRcca varunnu. I putiya saRkkassinRe uddEshaM
fOzhs (shakti, balaM, Ukk, karutt) AN<<+. ``n~aan yaatoru
saMshayavumillaate ezhutuM'' enn pazhaya sanpradaayaM;
``ezhutuM n~aanillaate yaatoru saMshayaM'' enn putiya rIti.
vaastavattil, niRmmatsaramaayi AlOcikkukayANen"kil,
raNTAmattEtin<<+ AdyattEtinekkAL kuRaccoru balaM jAstiyillE?
I kAraNaM koNTAN<<+ nammuTe praasaMgikanmAR I rItiye
avalaMbiccirikkunnat. malayALabhASa yUnivaRsiRRiyuTe
rakSaNattin kIzhil, nALkkunAL abhiv.rddhiprApiccu
varunnuNTennatin<<+ itiladhikaM entoru ``eviDansA''N<<+
nin"n"aLkk vENTat? I shailiyil cila paNDitanmAR
vidyARtthikaLkk DikRRERRu ceytukoTutta nOTTukaL n~An
kaNTiTTuNT. itinReyokke falaM yAtonnumaRiyAte A
paccappAvan"n"aL---nammuTe vidyARtthikaL(entAN<<+
nin"n"aLkkoru ciri?)---atokke paThiccu vashamAkkuM.
kramENa avaR vITukaLiluM I saMbhASaNarIti pracarippikkuM.

appOzhAN<<+ rasaM. pinne kELkkAM cila saMbhASaNan"n"aLin"n"ane.
``makanE, varAn skkULilninn tAmasiccatinn itrayadhikaM
kAraNament nI?'' ``acchA, bhASayil maRupaTi n~An I
paRan~n~Al manassilAkkuM en"n"ane nin"n"aL?'' itokke
anvayicc aRtthaM kaNTupiTikkunpOzhEkk makann kiTTENTat
kiTTikkazhin~n~iTTuNTAyirikkuM.

\chapter{can"n"alaMparaNTa TAgOR}

\noindent DiyaR saR,

nin"n"aLuTe sAhityalEkhakaneppaRRi (palE kAraNan"n"aLkoNTuM)
enikku paNTE nalla abhiprAyamilla. kazhin~n~a lakkattil
A manuSyan ezhutiya TAgORkaviyeppaRRiyuLLa upanyAsaM
n~AnuM vAyiccu. enikku piTicciTTilla. addEhattinn ruciccat
addEhattinn paRayAmen"kil, enikk rucikkAttat enikkuM
paRan~n~ukUTE? nin"n"aLellAM kUTi orubhAgattu cERnn enne
oRRaykku niRtti TAgOR kavita kEmamANennu vAdikkukayANen"kil,
mukhadAkSiNyaM vicAricc, ciladikkil tarakkETonnumillenn
n~AnuM pakSE, sammaticcEkkAM. pakSE, A sAhityadAsan paRan~n~at
EtAyAluM kavin~n~upOyi. itrayonnuM paRayAnilla.

n~an"n"aLuTe can"n"alaMparaNTayil oru kaviyuNT. vAsanAkaviyAN<<+.
buddhiyuM paThippuM illennaRtthaM. addEhattinRe pEru n~An
paRayukayilla. paRayAn~n~Alttanne avakAshikaLuNTAkuM.
addEhatte n~An veRuM ``misRRaR'' ennu viLikkAM. ``misRRaR''
ennu paRan~n~Al abaddhamAyi. kavitayezhutunna oru Dasan
mAsRRaRmAre san~jayan nEriTTaRiyuM. ``entinAN<<+, hE,
nammaLeppaRRiccat?'' enn avarokke cOdikkuM. san~jayann an"n"ane
paRRikkunna svabhAvamuNTO, hE?

atu pOkaTTe. I misRRareppaRRi cilatu paRayaTTe (misRRaR
muSin~n~AluM shari). iddEhaM TAgOR prasthAnakkAranAN<<+.
``itANO IshvarA, TAgOR prasthAnaM? ennAl TAgOR prasthAnatte
koTun"n"allUramma tanne kAkkaTTe!'' enn ennekkoNT AdyamAyi
paRayiccat I shrIjuttinRe kavitayAN<<+. ``can"n"alaMparaNTa
TAgOR'' ennAN<<+ iddEhattine iddEhattinRe snEhitanmAruM
TAgORinRe virOdhikaLuM viLiccuvarunnat.

oru divasaM rAvile addEhaM pARappuRattu kayaRivannu tAnezhutiya
oru kavitayuTe pakaRpp enRe kaivashaM tannu. kavitaykk
talavAcakamonnuM uNTAyirunnilla. TAgORin<<+ talakkuRipp
illapOluM! (addEhaM kELkkaNTa!) ``entu viSayatteppaRRiyAN<<+
nin"n"aLuTe kavita?'' ennu n~An cOdiccu. A vidvAn oru
TAgORcciri ciriccu. ``viSayamO? viSayamonnumilla. atokke
OLDfESanAN<<+. viSayaM! TAgORinn viSayamuNTO?'' n~An
aRiyukayilla. satyamAyiTTuM aRiyukayilla. atukoNT
yuktivAdikaLeppOle, uNTennuM illennuM n~An paRan~n~illa.
``nEtinEti'' n~An pazhaya prasthAnattiluLLa oru
ciriyOTukUTi talayATTi.

A can"n"alaMparaNTa TAgOR aviTeyirunnu prastuta kavita muzhuvan
ennekkoNT vAyippiccu. muzhuvan! ``enRe yOgaM!'' ennORttu n~An
paritapiccu. (in"n"ane entellAM kaSTappATukaL I curun"n"iya
jIvitakAlatt nin"n"aLuTe san~jayan anubhaviccu kazhin~n~u enn
nin"n"aLaRin~n~Al, san~jayan cirikkunnatinekkuRicc nin"n"aL
atbhutappeTuM. kaNNunIrAN<<+ san~jayann adhikaM yOjippenn
nin"n"aL paRayuM. akkatha pOkaTTe. atu maRakkuvAnANallO
n~An shramikkunnat.)

lain bai lainAyi n~Anatu muzhuvan vAyiccutIRttappOL,
nammuTe misRRaR at AdyaMmutal uRakke vAyikkuvAn ennOTAvashyappeTTu.
atu vAyiccu kELkkuvAn addEhattinn oru rasaM
tOnnITTuNTAyirikkaNaM. Aru kaNTu! san~jayan ezhutunnatukUTi
vAyiccukELkkunna cilarillE? ``bhinnaruciRhi lOkaH.''
enikkANen"kil, itokke eniyoru prAvashyaM enRe munpilninn
Aren"kiluM vAyikkumenn bhISaNippeTuttiyAl n~An pOlIssine
viLiccuvaruttuM. allen"kil ess. pi. si. E. kkAre (manuSyan
m.rgajAtiyilppeTTatallE?--DAR{}vin nOkkuka.)

can"n"alaMparaNTa TAgORinRe k.rti uRakke vAyikkuvAn
shramiccappOzhAN<<+ oru buddhimuTTu nEriTTat.
n~An AdyaM at (putiya prasthAnakkARkk perutt iSTamAya)
k.rSNagAdhAmaTTil vAyiccu nOkki; cErunnilla.
entezhutiyAluM van~cippATTAkumennu kETTirunnatinAl,
A maTTil oru vAyana naTatti; nIn"n"unnilla.
kiLippATTu parishOdhiccu; Avunnilla. kuRattippATTeTuttu......

kuRattippATTinRe ghaTTamettiyappOzhEkkuM kOpaMkoNTu
kaNNu kalan"n"iya shrIjutt enRe kayyilninnu kaTalAssu
taTTippaRiccirikkunnu. enikk sakalavuM parihAsamAN<<+;
avaRNNaR mAtramalla, savaRNNaruM kavitayezhuti
nannAyippOkunnatil n~An asUyayuLLavanAN<<+;
enneppOle dhikkAriyuM adhikaprasaMgiyuM can"n"alaMparaNTayililla;
ennokke A mahAkavi enne shakAriccu. aTi koNTupOyennu vicAriccu
n~An raNTu cuvaT dUre vAn"n"i amaRnn taTavinnorun"n"ininnu.
(enRe IshvarA! TAgORin<<+ in"n"ane dvESyamuNTen"kil
A shAntinikEtanattile kuTTikaL vaLarukayilla.)

oTukkaM addEhaM tanne kavita vAyiccu. veLiccappATinRe
aruLappATupOleyuLLa vallAtta oru rItiyilAN<<+
addEhaM vAyiccat. I rItiykk ``gadyapadya''mennANupOluM
pEr. TAgOR an"n"aneyANupOluM ezhutuka. addEhattinRe
kavitakaLuTe iMglISu taRjjamakaLAN<<+ gadyattiluLLatennAN<<+
n~An kETTiTTuLLat. pakSE, can"n"alaMparaNTa TAgORinRe
dvESyatte bhayann atu paRan~n~illa. EtAyAluM prastuta
gadyapadyatte nin"n"aLuTeyellAM anuvAdattOTukUTi
n~An tAzhe cERkkunnu. talavAcakamillenn AlOcikkaNE!
peTTenn taTan~n~ vIzharut!

\medskip

{\large
``enRe OmanE, enRe viLakku keTTupOyi.

hA! entANit? itentAN<<+? oru prakAshaM! Aritine iviTe koNTuvannu?

OmanE, n~An ceRutiriyAyi caman~n~ oru ceRiya mazhavilline
kuTayAyi piTicc nakSatran"n"aLuTe iTayil oru dinAntasan~cAraM
ceytukoLLaTTeyO?

tONikkArA, nI eviTeyAN<<+ ozhukkinnetirAyi pOkunnat?
n~An ninRekUTe varaTTeyO? enRe muRiyil viLakkillAttat
nI aRiyukayillennO?

erishshErikk uppupOrAttatukoNT n~An talayaNa mARRivaccu;
enniTTuM toTiyile kuran"n"an pOyillallO!!

hA, veLiccaM! veLiccaM! veLiccaM!!''
}

\medskip

eniyuM vaLareyuNT. pakSE atu muzhuvan ezhutuvAn nin"n"aL
ennOT Ajn~Apikkarut. ``shirasi mA likha, mA likha, mA
likha!'' enikk vallAteyokke tOnnunnu. oru ceRunAran"n"a
kUTi peTTennuLLa Avashyattinn I can"n"alaMparaNTayil
kiTTukayilla. atinn uzhalUR bhajARil pOkaNaM.
atukoNTAN<<+ n~An iviTe niRttunnat. kavita nin"n"aLuM
vAyiccuvallO. nin"n"aLkk ent piNNAkkAN<<+ manassilAyat?
nEru paRan~n~Al mati! tONikkAran kauNsil prasiDanRAN<<+;
tONi kauNsilAN<<+; ozhukk potujanAbhiprAyamAN<<+;
ennonnuM vyAkhyAnikkuvAn shramikkENTa. A vidyayokke
enikkuM kuREshshe aRiyAM.

pinneyoru cOdyaM: I viLakkinRe kARyaM tanne eTukkuka.
nammaLuTe viLakku keTTupOyAl nammaLentANu ceyyuka?
puzhavakkil pOyi tONikkArane viLikkukayANO?
atO, ``ennAl ini innu rAtri paNiyumeTukkENTa''
ennu karuti, kasEla nIkki ezhunnERR miNTAte
kiTannuRan"n"ukayO? I TAgORprasthAnakkARkk entupaRRi?
ivare en"n"ane nannAkkuM? oTukkaM kEss nin"n"aLuTe
ARyavaidyanRe aTukke ettumennAN<<+ tOnnunnat.

enikk paNT oru cillaRa kavitayuTe iLakkamuNTAyirunnu.
vaLare kalashalAyiTTonnumuNTAyirunnilla. vayanATan
panipOle iTaykku varuM, vannapOle pOkuM; kuRaccu
divasattEykk vAyil oru kayppu bAkkinilkkuM.
itrayE uLLU. A sukhakkETu mARRiyat I TAgOR
prasthAnakkAranAN<<+.

\chapter{kaLLavAkkukaL}

``tulyabhujasamAntaracatuRbhujaM'' enna vAkkinRe aRtthaM
paRayuvAn, tirakkAyi eviTeyen"kiluM pOkunna samayatt,
nin"n"aLe nirattinmEl taTan~n~uniRtti orAL AvashyappeTTAl
nin"n"aL entAN<<+ paRayuka? viSNusahasranAman"n"aLil
onnAyirikkumenn paRayuM. allE? ennAl at shariyalla.
it kaNakku pAThapustakan"n"aLil kANappeTunna oru
vAkkAN<<+. I vAkku ``ROMbas'' enna iMglISu vAkkinRe
gIR{}vANamANupOluM! entinAN<<+, TeksRRbukku niRmmAtAkkaLE,
nin"n"aL kuTTikaLe in"n"anE drOhikkunnat? ``ROMbas''
ennu tanne paThippiccAl entAN<<+ tarakkET? at
paricayamillAtta putiya vAkkAN<<+. shari, nin"n"aLuTe
``tulyabhujasamAntaracatuRbhujaM'' pazhaya vAkkANO?
atinRe aRtthaM kELkkunna mAtrayil manassilAkunnuNTO?
atinn valla aRtthavumuNTO?

\medskip

\centerline{``idaM catuRbAhukamAya rUpaM}
\centerline{mudA curukkITuka TeksRRukArE!''}

\medskip

enn n~an"n"aL nin"n"aLOT abhyaRtthiccukoLLaTTeyO?
tulyabhujasamAntaracatuRbhujaM pOluM!
tulyabhuja maNNAn"kaTTayAN<<+! drOhikaL!


\chapter{veLLaM, veLLaM}

inn paRan~n~atalla avaR nALe paRayuka enn san~jayan
kazhin~n~a lakkattil ArekkuRiccAyirunnu paRan~n~at?
O, shari! pAshcAtya gavESakanmAreppaRRi. ivaruTe I
peTTennuLLa abhiprAyaM mARRal koNT lOkattil entellAM
takarARukaLuNTAkunnu! san~jayann orikkal paRRiya
apakaTaM kELkkaNO? paRayAM.

nAlukollaM munpAN<<+. kaRkkaTakamAsaM. tiyyati
ORmmayilla. pakSE oru shaniyAzhcayANennORmmayuNT.
san~jayanRe jIvitattile sakala aniSTasaMbhavan"n"aLuM
uNTAyat shaniyAzhcakaLilAN<<+. san~jayan janiccatu
tanne shaniyAzhcayAN<<+. mEppaTi shaniyAzhca rAtri
san~jayan (maRRonnuM vAyikkuvAn kANAttatinAl) oru iMglIS
vaidyamAsika vAyikkukayAyirunnu. atil valiya parIkSAbirudan"n"aLuM
sthAnan"n"aLumokkeyuLLa oru tani veLLakkAran DOkTaR---%
gavESakan---``veLLa''ttekkuRicc orupanyAsaM
ezhutITTuNTAyirunnu. veLLamennu paRan~n~Al veLLaM tanne.
vATTaR. ``dhAtAvAdau camaccOrudakaM.''

san~jayan bahushraddhayOTukUTi A upanyAsaM vAyiccu.
entellAM saMgatikaLAN<<+ nammuTe veLLakkAran veLLatteppaRRi
upanyasiccat! atuvare svapnattilppOluM AlOcikkAtta etra
vivaran"n"aL! orALuTe Ayuss ayAL kazhikkunna paccaveLLatteyAN<<+
AshrayikkunnatennuM, analppamAya veLLaMkuTikoNT alpAyussu kUTi
akaRRAmennuM addEhaM vaLare yuktikaLuM kaNakkukaLumokke
kANiccu sthApiccu. oTukkaM addEhaM paRan~n~atAvit: ``veLLaM
itra kuTikkAmennilla. sadA veLLaM kuTikkuvAn sAdhikkunna AL
an"n"ane ceyyENTatAN<<+. IyiTe tekkE amErikkayile
146 vayassu prAyaM cenna oru manuSyanOT ayALuTe dIRghajIvitattinRe
kAraNamentenn oru patraRippORTTaR cOdiccappOL, ayAL
paRan~n~at rAppakal iTaviTAte paccaveLLaM kuTikkunna
tanRe shIlamAN<<+ ennAyirunnu. veLLaM shOdhanaye kramappeTuttunnu,
raktattile azhukkukaLe nIkkaM ceyyunnu; sharIrattil kaTanna
viSapadARddhan"n"aLe duRbalan"n"aLAkkunnu; uRakkatte
kramappeTuttunnu; talaccORine taNuppikkunnu; rOmakUpan"n"aLe
kazhuki v.rttiyAkkunnu. atukoNT bhayamillAte kazhiyunnETattOLaM
paccaveLLaM kuTikkuka: ArOgyattilEkkuM dIRghAyussilEkkuM uLLa
rAjamARggaM atAN<<+!''

an"n"unnE, san~jayan it vAyiccat nAlukollaM munpANE!
ann san~jayann strIkaLEyuM gavESakanmArEyuM bahu
vishvAsamAyirunnu. I upanyAsaM vAyiccu mAsika mEshappuRattu
vaccatOTukUTi nammuTe DOkTaR sAyippinRe ``sajaSan''
anusarikkuvAn san~jayan tIRccappeTutti. piRRE divasaM mutal
lOkattile mikacca veLLaMkuTiyanmAril orALAkuvAn san~jayan
uRaccu. kuRaccu kazhin~n~appOL, ``entinnu piRRE divasamAkkunnu?
ippOLttanne tuTan"n"ikkUTE? `shubhasya shIghraM' ennallE?
I cikitsakku valla celavumuNTO? kiNaRuM toTTiyuM kayaRumallAte
vERE valla orukkavuM itinnu ceyyENTatuNTO? A tekkE
amErikkakkAraneppOle 146 kollaM jIviccirunn lOkattinRe
bahumAnavuM, aTutta avakAshikaLuTe shApavuM orE samayatt
sanpAdikkunnat cillaRakkARyamANO?'' ennokke san~jayan
AlOciccutuTan"n"i. ann rAtritanne cikitsa AraMbhikkuvAnuM
nishcayiccu.

EkadEshaM oru paRa koLLunna oru pAtrattil niRaye veLLavuM
oru glAssuM san~jayan ORDaR ceytu. rAtri pattumaNikk
cikitsayuM tuTan"n"i. annu rAtriyuNTAya anubhavan"n"aLonnuM
n~An vistarikkukayilla. uRan"n"ITTillennumAtraM
curukkippaRan~n~EkkAM. pulaRccayAyappOL ``146 kollaM
jIvicciTTillen"kil entAN<<+?'' ennukUTi enikk tOnni.
pakSE n~An viTTilla. piRRE divasaM mAtra onnu
curukkukamAtraM ceytu.

piRREtte kollamAkunpOzhEkkuM, sAdhAraNa mithunaM onnAM
tIyativare mazha peyyAtirunnAl vaRRAtta pARappuRatte
kiNaRRinRe aTittaTT mInamAsattilttanne veLikku kaNTutuTan"n"i.
atinekkuRiccu vITTiluLLavaR parihAsamAyi OrOnnu paRayuvAnuM
tuTan"n"i. itiliTakku san~jayanRe vakayAyi veLLattinRe
guNagaNan"n"aLe prashaMsiccukoNTuLLa lEkhanan"n"aLuM
bhASaNan"n"aLuM anavadhi kazhin~n~irunnu. ennumAtramalla,
kuRRyATTUR vEdAntisamAjaM pOleyuM, ceRukunnatt bhasmaMtoTal
saMghatteppOleyuM, can"n"alaMparaNTayil oru ``veLLaMkuTissamAjaM''
sthApitamAyittIrukayuM ceytu. san~jayanAyirunnu atinRe
sthApakanuM, addhyakSanuM, nEtAvuM. kramENa atil aMgan"n"aL
vaRddhiccu. (lOkattil Etu kiRukkanAN<<+ pintAn"n"uvAn
ALukaLe kiTTAttat?)

veLLaM dEhattin<<+ ArOgyatte mAtramalla, AtmAvin<<+ shuddhiyEyuM
pradAnaM ceyyumenn san~jayan acirENa kaNTupiTiccu. atOTukUTi
n~an"n"aLuTe veLLaMkuTissamAjattinnu mataparamAya oru chAya
vannucERnnu. san~jayan oru purOhitanAyi, tala muNDanaM ceytu.
kASAyavastraM dhariccu. ``sAdhu jalaprasAd'' enn oru putiya pEruM
svIkariccu. cila shiSyanmAR bahumAnAtirEkaM koNT san~jayanekkuRicc
``can"n"alaMparaNTasvAmi'' ennumAtraM paRayuM. veLLaMkuTissamAjattinRe
pEruM perumayuM shuklapakSattile nilAvupOle, mazhakkAlatte jaladOSaM
pOle, ERRattile veLLaM pOle, v.rshcikattile man~n~upOle, AlinRe
vETukaL pOle, vaLarukayuM, puSTippeTukayuM, parakkukayuM ceytu.

san~jayan---athavA, sAdhu jalaprasAd---cikitsayuM tuTan"n"i.
anavadhipER mariccu. pan~camahAyOgan"n"aLuM kEsariyOgavuM
ottucERnna jAtakan"n"aLOTukUTiya cilaR jIviccu. avaruTe kayyil
ninn san~jayan saRTTifikkaRRukaL ezhutivAn"n"i, accaTippiccu,
shiSyanmArekkoNTu vitaraNaM ceyyiccu. veLLaMkuTissamAjattinu
nagaraMtORuM shAkhayuM, upashAkhakaLuM, pravaRttakasaMghan"n"aLuM
uNTAyi. samAjaMvakayAyi ``nayagARA'' ennoriMglISuvArikayuM,
``jaladEvata'' enna pEril oru malayALa mAsikayuM prasiddhIkarikkappeTTu.
eviTeyoru vARSikayOgamuNTO, aviTe sAdhu jalaprasAdinRe vakayAyi
oru paccaveLLaprasaMgavuM ozhiccukUTAttatANenna nilayAyi.

n~an"n"aLkk etirALikaLuM uNTAkAtirunnilla. (lOkattil Etu nalla
sthApanattinAN<<+ etirALikaLillAttat?) malabARile ``jUbili TI
klabbu''kAR n~an"n"aLuTe prasthAnatte pratiSEdhiccu;
tamiLnATTile ``ciricup{}piramaNiya cuvAmi cakAyaM kAp{}pI
kilap{}pu''kAR n~an"n"aLe etiRttu; kaLLuSAppukAR n~an"n"aLe
shakAriccu; RAkkuSAppulElakkAR n~an"n"aLe aTikkuvAn vaTTaMkUTTi;
bilAttimadyalaisansukAR n~an"n"aLeppaRRi pOlIs sUpraNTOT
mukhadAvil AvalAti paRan~n~u.

kaTappa, kaRnnUl, ballAri, AnandapuraM mutalAya jillakaLile
jaladauRbhikSyaM n~an"n"aLuTe prasthAnaM hEtuvAyi vaRddhiccirikkunnu
enna kAraNattinmEl cilaR madrAs kauNsilil n~an"n"aLeppaRRi
cOdyan"n"aL cOdippiccu. n~an"n"aL sOviyaRRuRaSyayil ninnu 
svakARyamAyi paNaM varuttuNTennu kANiccu cilaR gavaRmmENTilEkku
vAROlakaLayaccu. oru pOlIs inspekTaR oru divasaM sAdhu jalaprasAdinRe
Ashramattil orukUTTaM kaNsRREbiLmArOTukUTi etti, n~an"n"aLuTe
vArikayuTEyuM mAsikayuTEyuM viRRazhiccalAvAte poTipuraNTukiTakkunna
pantIrAyirattilcilvAnaM pazhaya lakkan"n"aL keTTiyeTuppiccu
``nin"n"aLkku kANiccutarAM!'' enna aRtthattil n~an"n"aLe oru
nOTTavuM nOkki sRRESanilEkku tiriccu.

pakSE itokkekkoNT n~an"n"aLuTe prasthAnattinu shakti kUTiyatEyuLLU.
sAdhu jalaprasAdinRe svantaM pEril samAjaM faNTenna vyAjEna
25,000 ka. bEn"kilAyi! ellArAjyan"n"aLiluM kUTi can"n"alaMparaNTasvAmikk
AyirakkaNakkAyi shiSyanmAruNTAyikkazhin~n~u. svAmikketirAyi
orakSaraMpOluM miNTunnavanRe tala aTiccupoLikkuvAn tayyARAya
oru dIRghakAyanAya veLLaMkuTiyanen"kiluM illAtta dEshamO, kugrAmamO
kEraLattil illAteyAyi. pattu mAnAn~ciRa niRakkuvAn matiyAya veLLaM
svAmiyuM shiSyanmAruMkUTi kuTiccutIRttu.

I samayattokke san~jayanRe manassAkSi entuceyyukayAyirunnu ennu
nin"n"aL cOdikkuM. san~jayanRe manassAkSikk oru kulukkavumuNTAyirunnilla.
oru valiya DOkTaR---pEreTutta oru gavESakan---tani veLLayAya oru
sAyp---anavadhi parIkSakaL pAssAyiTTuLLa oru ken"kEman---addEhamallE
paccaveLLaM rAvuM pakaluM, gAlaN kaNakkAyi uLLilEkku celuttunnat;
ArOgyattinuM dIRghAyussinuM vaLare paRRiyatANennu paRan~n~at?
A sthitikku sAdhu jalaprasAd Are pETikkaNaM?

an"n"ane kollaM mUnnu kazhin~n~u. cin"n"amAsaM. shaniyAzhca tanne.
I lEkhanAraMbhattil paRayappeTTa vaidyamAsikayuTe oru lakkaMkUTi
san~jayanRe kaiyiletticcERnnu. atiluM veLLatteppaRRi oru
upanyAsamuNT. ezhutiya AL ittavaNayuM valiya oru DOkTaR tanne;
pEreTutta oru gavESakan tanne; tani veLLayAya oru sAyp tanne;
anavadhi parIkSakaL pAssAya oru gaMbhIran tanne; pakSE,
adyatte ALalla. addEhattinRe upanyAsaM in"n"ane avasAniccu:
``mElezhutiya yuktikaLilninnuM, kaNakkukaLilninnuM,
paRyavEkSaNan"n"aLilninnuM teLiyunnat, manuSyaRkkuNTAkunna
sakala rOgan"n"aLuM amitamAya veLLaMkuTikoNT uNTAyittIrunnavayANennAN<<+.
kaSTiccu jIvikkuvAnAvashyamAya veLLaM mAtramE kuTikkAvU.
veLLaM AhArarasattinRe kaTTikuRacc atinRe pOSakashakti
illAtAkkittIRkkunnu. atisAravuM OkkAnavuM amitamAya
jalapAnattinRe aniSTafalan"n"aLAN<<+. atu raktattinREyuM
kaTTi kuRaykkunnu. itiniTe vaTakkE Afrikkayile 148 vayassAya
oru kAppiriv.rddhanOT patraRippORTTaRmAR ayALuTe dIRghajIvitattinRe
kAraNaM anvESiccappOL ayAL paRan~n~at, `n~An dinaMprati
oru uLLaMkayyilotun"n"unna veLLaM mAtramE kuTikkARuLLU.
atukoNTAN<<+ n~An in"n"ane AppIssnOTTaM uNakkamettITTuM
jIviccirikkunnat' ennAyirunnu.''

en"n"ineyAN<<+, an"n"attanmArE, koccammamArE, I gavESakanmAre
itinnushESaM nammaL vishvasikkuka? avaR paRayunnatu vishvasikkunna
pativ san~jayan niRttikkaLan~n~irikkunnu. sAdhu jalaprasAd
ippOL harikathakoNTumAtraM kAlakSEpaM ceyyukayAN<<+.
in"n"aneyuLLa lOkattil en"n"ane kazhin~n~ukUTuM? A bEn"kiluLLa
cillaRakkAsh aviTettanne uLLatu bhAgyaM!

\chapter{udyOgaM pOya vazhi}

n~An oru saMsthAnattile oru mantriyuTe praivaRR sikraTTaRiyAyirunnu.
mantriye talkkAlaM namukk blan"kiReDDi ennu viLikkAM.
(addEhattinRe sAkSAl pEr vEReyAN<<+; pakSE, at paRayAn
pATillallO) mantri ainpat vayass kazhin~n~a oru mahAdIRghakA%
yanAyirunnu. taTicca dEhaM, kaRutta niRaM, cukapp chAyayuLLa kaNNukaL,
pannirOmattOTukUTiya cevikaL, iTun"n"iya neRRi, mEppile
tekkE AfrikkapOleyuLLa mUkk, nATakakkArOTu kaTaMvAn"n"i
veccukeTTiyatANennu tOnnikkunna bhayan"kara mIsha, kAppiriyuTe
cuNTukaL, AkappATe, ``akkOlaM kaNTupOyaalatumati cuTalappoTTanuM
n~eTTivIzhuM.'' n~AnAkaTTe bi.E. parIkSa pAssAya oru
svatantracintakanumAyirunnu.

A mIshavecca pUn~cOlakkara ETattil accanRe praivaRR
sikraTTaRiyAyi kayaRRaM kiTTi patinan~cudivasaM kazhiyunnatinu
munpAN<<+ n~An iRan"n"ippOkENTivannat. gavaRmmeNTudyOgavuM
n~AnuM tammiluLLa akAlikamAya I vERpATinu hEtuvAyittIRnna
saMgatiyil kuRRakkAran n~AnO mantriyO ennu tIRccappeTuttENTatu
vAyanakkArAN<<+. n~An putiya jOliyil pravEshicca divasaM
mantrikku kiTTiya mUnnu nivEdanapatran"n"aLkk maRupaTi
ayaykkENTunna bhAraM A mlEcchan enne Elppiccu. vaLare
k.rtyaniSTayOTuM IshvaravicArattOTuM kUTi mantri tanna
Ajn~akaLe aNupOluM teRRikkAte n~An avaykk AvuMpOle
maRupaTikaLuM ayaccu. I maRupaTikaL kiTTiyavaR patt
divasattinakatt avayokke mantrikkutanne maTakkiyayaykkukayANuNTAyat.
ReDDigAru atokke vAyiccu; enne viLikkAn shipAyiye ayaccu; n~An cennu.
mantri kOpaMkoNT viRaykkunnu. kaNNukaL cuvanna blOTTin"n"pEppaRpOle
Ayirikkuunnu. enRe IshvarA! itra dvESyaM n~An oru mantrikkuM
amantrikkuM vannu kaNTiTTilla. I vayassinnakatt kaNTiTTilla.

ReDDi enne shakAriccu; n~An ReDDiyEyuM shakAriccu. ( AdyaM
shakArikkunna ALallE, sAR, AlOcikkENTat?) addEhaM mEshappuRatt
patt prAvashyaM iTiccu. n~An peTTennuLLa AvEshattil
oriTi iTiccat mEshayuTe kURtta kONilAyippOyi. at kaNTiTTukUTi
A mahApApiykku ciri vannilla. pinneyuM n~an"n"aL vaLare nEraM
hanumAnuM bhImasEnanuM ceytatupOle parasparaM shakAriccu.
oTukkaM mantri enRe maRupaTikaLellAM curuTTi enRe
mukhattEykkeRin~n~, enne Dismiss ceytirikkunnu ennu paRan~n~u.
A kaTalAssucuruL kunin~n~eTutt patt kutirashshaktiyOT </m>
(Horse Power) <m> kUTi an"n"OTTuM eRin~n~atinnushESaM
n~An puRattEykk cATi AdyaM kaNTa TrAM vaNTiyil
kayaRippOvukayuM ceytu.

itAN<<+ katha. eni RikkARDukaL kUTi onnu parishOdhiccu
nin"n"aL vidhi paRan~n~ukoLLuvin. enRe maRupaTikaL
avayuTe caritran"n"aLOTukUTi n~An kOTati munpAke
samaRppikkunnu.

kATTukuLaM tAlUkkinRe ERRavuM kATupiTicca mUlayil `pEkramAnceLLa'
ennoru kugrAmamuNT. pakSE, aviTeyuLLa nivAsikaL muzhuvan
mantriyuTe kakSikkArANatrE (itokke AraRin~n~u?). pEkramAnceLLayil
oru tapAlAppIss sthApiccu kiTTaNamenn apEkSiccukoNTuLLa
aviTutte pauranmAruTe harajiyAyirunnu AdyattEt. I harajikk,
A pradEshatt oru tapAlAppIssinRe AvashyaM vaLareyillennuM,
vidyAbhyAsapracaraNaM, samAdhAnaparipAlanaM, mutalAyavayilAN<<+
aviTutte nivAsikaL adhikaM manassiruttENTatennuM, akkARyattil
gavaRmmeNT avare sahAyikkunnatANennuM maRRuM yuktiyuktamAyuM
d.rSTAntattOTukUTiyuM vivaricc oru maRupaTi ayaykkENamenn
mantri ennoT kalppiccirunnu.

I kalpanaprakAraM vaLare vaLare AlOcicc n~An tayyARAkki ayacca
maRupaTi itAyirunnu:

{\it``pEkramAnceLLakkAruTe tapAlAppIss harajiykkuLLa maRupaTi:---

nin"n"aLuTe haraji kiTTi. itra buddhishUnyatayuM dhikkAravuM niRan~n~a
oru haraji I AppIssil ituvare vanniTTilla. buddhi nin"n"aLkkilla;
lajjayuM illAte pOyallO, ennAN<<+ enRe vyasanaM.

nin"n"aLkk iviTe oru tapAlAppIss vENaM illE? entinANupOluM
aviTe oru tapAlAppIss? Et muzhubhrAntanAN<<+ pEkramAnceLLaykku
kattayaykkAn pOkunnat? ayaccAlttanne A ezhuttu vAyippAn{}mAtraM
akSarajn~AnaM aviTe etrapERkkuNT? A pradEshattukUTi
kaTannupOkENTivarunna inSURans kavaRukaLkk ArAN<<+
uttaravAdittamERReTukkuka?

tapAlAppIss! nin"n"aLkku vEReyonnuM vENTE? oru tuRamukhavuM
niyamaniRmmANasabhayuM haikkOTatiyuM kUTiyAyAlO?
nin"n"aLkkaviTe vENTunnat oronnAntaraM jayiluM
majisTrERRukOTatiyuM pOlIs sRRESanuM oru elimenRaRi skULumAN<<+.
tapAlAppIssinRe pER inimElil miNTarut.''

}

itAN<<+ n~Anayacca maRupaTi. itil entAN<<+ hE, oru teRR?
I maRupaTi hEtuvAyi aTutta tiran~n~eTuppukAlatt ReDDigAruve
pEkramAnceLLayuTe pantraNTu mayitsinuLLileviTeyen"kiluM
kaNTupOyen"kil veTiveccukaLayumennu pEkramAnceLLayilninnu
cila vAROlakaLkUTi mantrikku kiTTiyatrE. ceLLakkAruTe
tOnyavAsattinu n~AnANO uttaravAdi? aviTe oru tapAlAppIssinRe
Avashyakatayillenn itiluM yuktiyuktamAyuM d.rSTAntattOTukUTiyuM
ippOzhatte praivaRRusikraTTeRi ezhutaTTe! an"n"ineyallE
miTukku nOkkENTat?

atan"n"ine. raNTAmatte haraji oru jalavitaraNapaddhati
naTappil{}varuttuvAn kuRE paNaM kaTaM cOdiccukoNTuLLa uzhalUR
munisippAliRRiyuTe paridEvitamAyirunnu. tiran~n~eTupputORuM
uzhalUR munisippAliRRiyilninnu irunURu vOTTukaL ReDiyAyi
ReDDigAruvinu kiTTARuNTatrE. pakSE, jalavitaraNapaddhati
ippOL naTappil varuttuvAn taramillennuM, at avarOTatra
paccayAyi tuRannupaRan~n~ avare muSippikkarutennuM, oruvidhaM
vAyiccAl aRtthaM manassilAkAtta sanpradAyattil an"n"umin"n"uM
toTAtta rItiyil oru maRupaTiyAN<<+ koTukkENTatennumAyirunnu
mantriyuTe kalpana.

etrayO nEratte gUDhAlOcanayuM an~cu sigaraRRuM (annu
sigaraRRuvaliyAyirunnu pradhAna jOli) celavAkkiyatinnushESaM
n~An in"n"ane ezhuti ayaccu:

{\it ``uzhalUR munisippAl cERmAnn:

nin"n"aLuTe harajiyil prastAvikkappeTTa jalavitaraNapaddhatiye%
ssaMbandhiccETattOLaM avagADhamAya AlOcana, EtadviSayakamAyi
gavaRmmeNTu naTattiyatinRe falaM pratIkSiccirikkappeTTirunna%
tAyEkkAvunnapOleyuLLa dhanasaukaRyaM ikkollatte baDjaRRumukhEna
kiTTiyiTTillennuLLat aniSEdhyamAyirikkE, I sahAyaM tatkAlaM
valiya tOtil ceyyappeTuvAn asAdhyamAyttIRnnEkkAmennuLLatANenn
anumAnikkunnatil valiya teRRuNTennu paRayuvAn n~An orikkaluM
orukkamallen"kiluM, pratyEkasaMgatikaLil sAmAnya niyamattinu
pakaraM pratyEkapramANan"n"aLe cilappOL prav.rttikkAspadamAyi
svIkarikkENTatANennuLLa tattvatte puraskaricc, cila
munisippAliTTikaLuTe kARyaM sAmAnyavidhiyilninnozhivAkki
niRttunnat nyAyamAyirikkumO ennuLLa saMgati gavaRmmeNTinRe
shraddhaykk viSayIbhaviccirikkunnatinAl an"n"ine ozhivAkki
niRttunnatine, nin"n"aLuTe munisippAliRRiyessaMbandhicciTattOLaM
sAdhUkarikkunna vastutakaLeyuM yuktikaLeyuM gavaRmmeNTine
oru memmORiyal{}mUlaM aRiyikkunnatu niSfalamAyittIruvAnAN<<+
iTayuLLatennAlOcikkENTatillennu n~An nin"n"aLkk uRapputarunnu.
pakSE, ikkARyattil mun{}paRan~n~a RippORTT I ezhuttu
kiTTiyashESaM nAlpatteTTu maNikkURinuLLil ayaykkENTatANennukUTi
n~An upadEshikkunnu. enRe sahAyaM etra vENamO atra
itilumuNTAyirikkumennu n~An paRayENTatillallO.''

}

itAyirunnu san~jayan tayyARAkkiya maRupaTi. itil Adyatte vAcakaM
n~An oru vIRppil ezhutiyatANen"kiluM an"n"umin"n"uM toTAyma
enna guNaM atil muzhaccunilkkunnuNTennAN<<+ enRe abhiprAyaM.
enniTTentAN<<+? entu kAraNaM koNTO, mantrikk atu piTiccilla.
I cETTakaLeyokke mantrimArAyi nishcayikkunnuvallO!
in"n"aneyoru vakatirivillAtta vaRggaM! nin"n"aL mUnnAmatte
maRupaTiyuTe kathakUTi kELkkaNaM (vaLare nINTupOyO
ennaRin~n~illa).

entO cila kAraNan"n"aL hEtuvAyi kan~cAvUR DisTrikT bORDinu
tan"n"aLuTe prasiDanRine tiran~n~eTukkuvAnuLLa adhikAraM
gavaRmmeNTu Radduceytu. tan"n"aLkku tiran~n~eTuppadhikAraM
vINTuM kiTTaNamennu DisTrikT bORD oru harajiyuM ayaccu.
kan~cAvUR DisTrikT bORD maRRu DisTrikT bORDukaLeppOleyalla.
atile menpaRmAR muzhuvan ReDDigAru avatArapuruSanANennu
vishvasicc A asattine ArAdhikkunna van"kashirOmaNikaLAN<<+.
kan~cAvUR DisTrikTile vOTTukaLkoNTAN<<+ A kazhuvERi
ellA tiran~n~eTuppukaLiluM jayikkunnat. pakSE, DisTrikT
bORDinRe I apEkSa svIkarikkuvAn mantrikku dhaiRyamuNTAyilla.
atukoNTu harajikkARyatteppaRRi ERRavuM laghuvAyi mAtraM
spaRshiccukoNTuM, tIRccappeTutti yAtonnuM paRayAteyuM,
pakSE avare ERRavuM rasippikkukayuM anunayippikkukayuM
ceyyunna rItiyiluM oru maRupaTi tayyARAkkuvAn mantri
ennOTAjn~Apiccu.

n~An ezhuti; n~An ezhutiyatineppaRRi n~An{}tanne an"n"ine
paRayAn pATillen"kiluM vAstavattil sARE, etra dvESyamuLLavanAyAlkkUTi
A ezhuttezhutiya ALuTenEre muSiyuvAn ARkkuM tOnnukayilla.
in"n"ine snEhaM tuLLittuLunpunna orezhutt n~An atuvareyO
atil pinnITO ezhutITTilla. kan~cAvUR DisTrikT bORDile
ellA menpaRmAruM ainpatu vayassinnappuRattuLLa v.rddhanmArAN<<+.
avare n~An prasAdippikkuvAn shramiccatiluM adhikaM
AruM prasAdippikkuvAn shramicciTTuNTAyirikkukayilla.
allen"kil n~AnentinAN<<+ I mukhavurayokke ezhutunnat?
ezhuttutanne iviTeyuNTallO. nin"n"aL vAyiccunOkki
abhiprAyaM paRayuvin.

{\it

``kan~cAvUR DisTrikT bORD menpaRmARkk:

\noindent priyappeTTa kAraNavanmArE,

nin"n"aLuTe haraji kiTTi. enRe uRRa bandhukkaLuM snEhitanmArumAya
nin"n"aL entAN<<+ yAtoru harajiyuM ayaykkAttat? nin"n"aL enRe
nEre oTukkaM muSin~n~uvO? ennuM maRRuM viSAdicc, neTuvIRppiTT,
kauNsilil vAdaprativAdan"n"aL naTakkunnatiniTayil{}kkUTi
iTaykkiTe kaNNunIR vARttu n~An kAlaM kazhikkukayAyirunnu.
appOzhAN<<+ sauhARddamas.rNavuM snEhasubhagavuM
maitrIsurabhilavumAya nin"n"aLuTe haraji kiTTiyat; hA,
entoravAcyamAya AnandaM! A ezhuttu kiTTiya divasaM
enikkoru sudinamAyirunnu.

pinne oru kARyaM. aviTe mazha peyyunnuNTO? hU. iviTutte
mazhayuTe kARyaM paRan~n~AlaRRamilla. rAppakal, anadhyAyamillAte
peyyunnu! aviTeyuM an"n"inettanne mazhayANen"kil nin"n"aL
adhikaM puRattiRan"n"i naTakkarutE! nin"n"aLkkARkkuM
kuTTiprAyamalla; atAlOcikkaNaM. bORDinRe kARyamokke
aviTe nil{}kkaTTe, `sharIramAdyaM khalu dhaRmmasAdhanaM'.
cumaruNTen"kilE citramuLLU. tAn cattu mIn piTicciTTentukARyaM?

nin"n"aL mEl tEykkuvAn entu kuzhanpAN<<+ upayOgikkunnat?
dhAnvantaratailamAN<<+ nallat. enRe praivaRRsekraTTaRiyuTe
rAjyamAya malabARil onnAntaraM dhAnvantaraM kiTTuM.
kan~cAvUR kazhin~n~Alppinne enikk malabAROTAN<<+ adhikaM
iSTaM. n~An aviTe orikkal pOyiTTuNT. nalla rAjyaM;
ALukaL mAtraM oruvahakkArAN<<+.

bORDukARyan"n"aL nOkkikkazhin~n~Al dinaMprati nin"n"aL
bhaktiviSayakamAya valla pustakavuM vAyikkaNaM. Eten"kiluM
oru shAstriye varutti bhAgavataM vAyicc aRtthaM paRayiccAl
vaLare guNamuNTAyirikkuM.

enikk eniyuM ezhutaNamennuNT. pakSE, priyavayOdhikanmArE,
jOlittirakk pratibandhamAyi nilkkunnuvallO. en"kiluM
n~An nin"n"aLuTe akrItadAsanANennuLLa kARyaM nin"n"aL
vismarikkarutE! nin"n"aLkkuvENTi ellA kARyan"n"aLuM n~An
ceyyuM. iTaykkiTe sukhavivaraM ezhutuvin---in"n"ine
maTiyanmArAyAlO?''

}

n~An ayacca maRupaTi itAN<<+. itu kaNTiTTAN<<+ mantri
adhikaM kSObhiccat. itil entAN<<+ adhikaM kSObhikkuvAnuLLat?
Etu kaThinah.rdayattOTukUTiya bORDAN<<+ it
vAyiccaliyAtirikkuka? pakSE atokke paRan~n~iTTentAN<<+,
enRe udyOgaM gamayAn~cakAra--atrayallE paRayENTU?

\chapter{cila putiya veppumuRakaL}

{\footnotesize pOlIssO, hel{}tt
DippARTTumenRukArO taTan~n~illen"kil aTuttutanne
prasiddhIkarikkuvAn pOkunna ``mahAbhakSyabhAkSyaM''
enna pAcakagranthattil ninn cila bhAgan"n"aL.}

\section{pITikaccAya}

cila pAcakagranthan"n"aLil cAya tayyARAkkuvAnuLLa vidhi
vivariccukANunnu. pakSE, I vidhiprakAraM cAya
tayyARAkkittuTan"n"iyAl kOppaykk arayaNavilayAyi
cAya vilkkunna nammuTe klabbukARkk OrO kOppayilninnuM
raNTu paiyiladhikaM AdAyamuNTAvukayilla. avaruTe ippOzhatte
tOtuprakAraM oru kOppayilninn an~cupai AdAyamuNTAkkaNamen"kil
oru pratyEkarItiyil{}ttanne cAya uNTAkkaNaM. it saR{}vIsuLLa
kaTakkARkk suparicitamANen"kiluM, pututAyi klabbukaL
tuTan"n"uvAn uddEshikkunnavaR kuzhan"n"ippOkunnu.
pAcakacintAmaNiyilO, ARyabhakSyapAcakavidhiyilO,
khAnAkittAbilO onnuMtanne I sanpradAyaM vivarikkappeTTiTTilla.
pazhaya cAyakkaTakkAR konnAluM putiyavaRkk I rahasyaM
paRan~n~ukoTukkukayumilla. atukoNT attaraM putumakkAruTe
saukaRyatte uddEshiccumAtramAN<<+ pITikaccAyayuTe
niRmmANavidhi iviTe vivarikkappeTunnat.

\noindent oru kOppa cAyaykk:--

tiLaykkunna veLLaM kOppa~1;
ATTin{}pAl, pashuvin{}pAl,
erumappAl ivayuTe mikscaRil nAliraTTi veLLaM cERttu
kuRukki mUnniraTTiyAkkiya pAl TEbiL spUN~1;
pan~casAra TIspUN~2;
anavadhiprAvashyaM upayOgiccuM uNakkiyuM sUkSicca
cAyaccaNTi TIspUN~2;
kokkuMmUTiyuLLa Tin{}pATTa~1;
valiya inAmal TaMblaR~2;
nINTa TIspUN~1;
arippakkOrika~1;
atinRe kanpivala kIRiya dOSaM pariharippAn
v.rttikeTTa shIlakkaSaNaM~1;
kOppa~1;
sOsaR~1;
(kOppaykkuM sOsaRinnuM pakaraM oru glAss TaMblaRAyAluM mati)

\noindent niRmmANakramaM:

cAyaccaNTi Tin{}pATTayiliTTu mIte tiLacca veLLamozhicc
mUTikoNT bhadramAyi aTaccuvekkuka. anantaraM cAya kuTippAn
vanna ALukaLuTe mEshappuRattuninn pazhattoli, appakkaSaNan"n"aL
(miliTTaRi DippARTTumenRukUTiyuNTen"kil ellinkaSaNan"n"aL)
mutalAyavayuM, atinmEl keTTinilkkunna ceRiya cAyattaTAkan"n"aLuM
oroRRa vanpicca tuTaykkalinn A niRbhAgyavAnRe maTiyilEykku
sthalamARRaM ceyyuka. atinnushESaM ayALkk AvashyamuLLa
palahAran"n"aL saplai ceyyAM. appOzhEkkuM cAyaccaNTiyile
viSaM muzhuvan veLLattilEkku saMkramiccukazhin~n~iTTuNTAyirikkuM.
uTane cenn mun{}paRan~n~a arippakkaraNTiyil A v.rttikeTTa
tuNikkaSaNamiTT atilUTe pATTayilninn cAyaveLLaM inAmal
TaMblaRilozhikkaNaM. atinOTu pAluM pan~casArayuM cERttu
curun"n"iyatu raNTu minuTTen"kiluM A nINTa spUN TaMblaRiliTT
marakkottan puRappeTuvikkunna shabdaM pOle shabdamuNTAkkuka.
pinnIT maRRE inAmal TaMblaRupayOgicc an~cARuprAvashyaM
cAya ARRiyatinnushESaM kOppayilO, glAss TaMblaRilO ozhiccu,
palahAraM muzhuvan bhakSiccutIRnnu maccunOkki japikkunna
vidvAnRe munpAke mEshappuRatt ``DhiM'' enna shabdattOTukUTi
nikSEpikkuka.

\section{brAmiNs TI}

itin<<+ esenscAya ennuM paRayAM. nAlAMklAs cAyappoTiyilninnu
veLLaMcERttu kuRukki vaRRicc pizhin~n~eTukkunna,
kaypurasattOTuM eNNaccuvayOTuM kUTiya mahA kALakUTatteyAN<<+
``esens'' ennu viLiccuvarunnat. paramEshvaran paNTu vizhun"n"iyatuM,
pAR{}vvati kazhuttil kayaRi piTikUTiyatinAl vayaRRilettAte
ettiyETattu tan"n"ininnatumAya sAdhanaM I ``esensA''Nennu
shivapurANattil vivaricca bhAgatte, intyayile ``pirAmiNAL
kAp{}pI kilap{}pu''(an"n"aneyAN<<+ tamizh lipiyilezhutuka)%
kAruTe jOyiNT bhImaharaji hEtuvAyi liRRaN prabhuvinRe
vAzhcakkAlatt intyAgavaRmmeNT nIkkaM ceytatANennu oru
janashrutiyuNT. kARyattinRe vAstavaM paTaccavanorAL kaNTu.

itinoru meccaM mottattil AdyaM vivaricca cAyayekkAL itinnu
celavuM adhvAnavuM curun"n"umen"kiluM (A spUN koNTuLLa
maraNayaTikkutanne koTukkAM oru pai) itinnu vila
jAstiyAkkAmennuLLatAN<<+. ``pirAmiNALu''Te ellA
ERppATukaLkkuM sAdhAraNayAyi vila kon~caM kUTutalAN<<+.
pakSE, (kARyaM paRayaNamallO) v.rtti kuRaccadhikamuNTAyirikkumennoru
meccamillAteyumalla.

pinneyoru vyatyAsaM brAmiNs TI koTukkunnatinn munp oru mantraM
collENamennuLLatAN<<+. klabbile nAyaRcekkan mun{}vivaricca
vidhattiluLLa mEshatuTakkal naTattiyatinu shESaM sAkSAl svAmiyO
kuTTissAmiyO cAyakuTiyanRe mun{}vashattu hAjarAyi raNTu kaiyuM
mEshappuRatt Unni munnOTT cAn~n~ tAzhe paRayunna mantraM
shvAsaM viTAte uccarikkaNaM.

{\it ``shUTA iDlisAnpARpUriuruLakkizhan"kcaTNiRava dOshai%
yup{}mAbONTakArAppuntikEbEj{}vaTairasavaTaimasAlavaTai
tairuvaTai OmAppoTipakkavaTai ellAmirukk sAR ennA vENaM
sAR shollun"kO sAR.

apraM svITs laDujilEbimaisURpAkk shUTAsEmiyAppAyasaM%
shUTAshEmiyAkEsari hal{}vAyilaTai ellAmirukk sAR
ennAvENaM sAR shollun"kO sAR shollun"kO!!''}

onnuM vENTennAN<<+ maRupaTiyen"kil, cAya koTuttatinu
shESavuM I mantraM AvaRttikkAM. in"n"ine brAmiNs TI.

\section{misRRik pAyasaM}

it misRRik kavitayezhutishshIlikkunna yuvakavikaLkk
misRRisisalahari piTikkuvAnuM, atu piTiccu kazhin~n~avaRkku
vaRddhikkuvAnuM bahukaNakkAyi paRRunna oru yOgamAN<<+.
vaLarekkAlaM sAkSAl mahAkavi TAgORinRe veppukAranAyirunna
oru misRRik pAcakanAN<<+ I yOgaM kaNTupiTiccat. itinRe
niRmmANavidhi upadEshikkuvAn n~an"n"aL A dEhattinRe
vITTinRe paTikkal anavadhi divasaM (vratattinRe tIvrata
jAstiyAkkuvAnAyi) kurumuLakukaSAyaM mAtraM kuTiccu satyAgrahaM
anuSThiccu kiTakkENTivanniTTuNT. it onnAmatte prAvashyaM
prasiddhappeTuttukayAN<<+. patrAdhipaR anumati tannAluM
tannillen"kiluM taRjama ceytu prasiddhappeTuttuvAn pATilla.

\noindent orALkk kazhikkuvAnuLLa pAyasattinAvashyamAya
sAdhanOpakaraNan"n"aL:--

man~n~utuLLikaL auNs~12; pulleNNa auNs~8; ARRile
svacchajalaM auNs~6; marubhUmiyile uRavil{}ninnuLLa
veLLaM auNs~4; putumEghattil{}ninnAdyaM vIzhunna mazhaveLLaM
auNs~2; naRuM pUntEn auNs~1; mullappU, ceMpanIRppU,
poncenpakaM, ivayil OrOnninREyuM daLan"n"aL~24; kastUri,
cen"kun"kumaM, veNkaRppUraM iva OrOnnuM uRuppikattUkkaM~1;
kuzhiyammi~1; ammikkuzhavi~1; tUveLLikkiNNaM~1.

\noindent niRmmANakramaM:--

itinRe niRmmANakramamAN<<+ mahAviSamaM. kARozhin~n~a
kaRuttavAvudivasaM rAtriyil prastuta sAmAnan"n"aLellAM
keTTiyeTutt oru uyaRnna kunninmEl kayaRi nakSatran"n"aLuTe
veLiccattil pUvitaLukaLellAM kUTTi kuzhiyammiyiliTTaraccu
tUveLLikkiNNattilAkki mIte mun{}paRayappeTTa veLLan"n"aLellAM
ozhiccu mayilppIlikoNT iLakkiccERkkuka. pinnITu kastUriyuM
kun"kumavuM kaRppUravuM vERe araccu cERkkaNaM. oTukkaM
pUntEn mElpoTicERtt malaRnnu kiTannu kuTikkuka. I araykkaluM,
iLakkaluM, kuTikkaluM naTakkunpOzhokke raNT misRRikkOmanakaL
kaviyuTe iTattuM valattuM ninn, pratyEkiccu kAraNamonnumillAte,
viSAdAtmakattOTukUTi karan~n~ukoNTirikkaNaM. tadanantaraM
kunninmElninn tAzhe iRan"n"ivann mEppaTi misRRikkOmanakaLekkoNT
pularunnatuvare talaykk nellikkaveLLamupayOgiccu dhAra
naTattuka. dhAra kazhin~n~atinnushESaM A vidvAn
saMsArikkunnatokke misRRik{}kavitayAyirikkuM. itetrayO
gOpyamAya oru yOgamANennu sUcippiccat vAyanakkAR maRannu%
kazhin~n~uven"kil onnukUTi ORmmappeTuttikkoLLunnu.

\section{viSAdAtmakaccaTNi}

viSAdAtmakatvaM aTan"n"iya kavita ezhutaNamen"kil
AdyantaM kaNNunIrozhukikkoNTirikkENTat atyAvashyamANatrE.
pakSE, kavita ezhutuvAn tOnnunpOzhokke kaNNunIruNTAkattakka
vyasanaM ellAvaRkkuM ellAkkAlattuM uNTAyirikkuvAn
iTayillAttatinAl, dinaMprati DasankaNakkAyi vaRddhiccukoNTirikkunna
nammuTe viSAdAtmakanmARkkuvENTiyAN<<+ I caTNiyOgaM
n~an"n"aLuTe pAcakashirOmaNi kaNTupiTiccirikkunnat.

\noindent irupattinAlu vari viSAdAtmakakavitaykku vENTunna sAmAnan"n"aL:

ceRiya cukanna uLLi eNNaM~50; kurumuLak RAttal onn;
cukk RAttal ara; paccamuLak, kappal{}muLak, kAntArimuLak
OrOnnuM uRuppikattUkkaM~1; veLLaM iTan"n"azhi~1.

AdyaM cukkuM kurumuLakuM cataccu veLLattiliTT pAtrattinRe
vAya mukkAluM mUTi aTiyil tI katticc veLLaM nAlilonnAkunnatuvare
kuRukki cUTARippOkAtirikkuvAn kanalil{}ttanne vekkuka.
anantaraM uLLi nannE ceRutAyarin~n~u pacca--kappal--%
kAntArimuLakukaLOT kUTTiccERttaraccu kuREshsheyAyi bhakSikkuka.
atu kazhin~n~a uTaneyAN<<+ kanalil{}ninnu cukkumuLakukaLuTe
kaSAyameTutt cUTARRAte, kaNNaTacc, iTaykk viramikkAte
kuTiccutIRkkENTat. kavitayezhutuvAnuLLa kaTalAssuM pEnayuM
kaNNunIR vIzhuvAnuLLa pAtravuM mun{}kUTTi tayyARAkki
veccukoLLaNaM. pinnIT ava tiran~n~unaTakkuvAn
samayamuNTAvukayilla.

\chapter{bhaR{}t.rsthAnARtthikaL}

akattirikkuM vanitaykk oru viLi tOnni. avaL puRattEkkiRan"n"i.
janananiyantraNattinRe atyAvashyakatayeppaRRi avaL prasaMgiccu;
strIkaLkk ellAkAlattuM, ellAyiTattuM, ellA saMgatikaLiluM
puruSanmAreppOle pOrA, avaR{}kkuLLatinekkAL kuRaccadhikaM tanne
svAtantryaM vENamenn avaL prakhyApanaM ceytu. janananiyantraNatte
prAyOgikamAkkuvAn, strIsvAtantryEcchaye safalIkarippAn, avaL
pala pala nUtanamARggan"n"aLeppaRRiyuM gavESaNan"n"aL naTatti.
avaye atatu samayattu janan"n"aLkku sammAniccu. kAlaman"n"ine
kazhin~n~u.

avaLuTe pEriviTe paRayunnatu pantiyalla. kAraNaM A pEruLLa
vERE strIkaL atE abhiprAyakkArikaLANen"kil, avare uddEshiccAN<<+
n~Anezhutunnatennu karuti enRenEre avaR kalashalAyi muSiyuM;
bhinnAbhiprAyakkArikaLANen"kil, tan"n"aLuTe pErinOT A
abhiprAyatte tunnippiTippiccatinn atiluM kalashalAyi
muSiyuM. atukoNT n~An avaLe `saubhAgyavati'yennumAtraM
viLikkAM. A pER sARtthakavumAN<<+; avaLoru saubhAgyavati
tanneyAN<<+.

avaLuTe prasaMgan"n"aL kEL{}ppAn ALukaL nAnAbhAgattuninnuM
AyirakkaNakkAyi etticcERnnu ennu paRayunnat svantaM
RippORTTaruTe atishayOktiyalla. veRuM paccapparamARtthamAN<<+.

</m>
\begin{verse}
<m>

``kAvyaM sugEyaM; katha rAghavIyaM;\\
kaRttAvu tun~cattuLavAya divyan;\\
collunnatO bhaktimayasvaratti;--\\
lAnandalabdhikkiniyentu vENaM?''

</m>
\end{verse}
<m>

\noindent ennu mahAkavi vaLLattOL cOdiccatupOle,

</m>
\begin{verse}
<m>

``sabjakRRu `kaNTrOL'; paRayunnatO strI;\\
shabdaM suvINAkvaNanOpamaM tAn;\\
vayassu pattonpatinippuRattA;--\\
NALttirakku kUTAniniyentuvENaM?''

</m>
\end{verse}
<m>

\noindent enn n~AnuM cOdikkAM.

saubhAgyavatiyuTe prasaMgaM kELppAn tikkittirakkikkUTiya
janAvaliyuTe oru valiya shatamAnaM AnandapAravashyaM koNT
matimaRanna puruSanmAruM, bAkki asUyakoNT kaNNukaTi tuTan"n"iya
mahiLakaLumAyirunnuvennu n~Anini eTuttupaRayENTatillallO?

an"n"aneyirikke, oru divasaM, oru prasaMgavELayil, saubhAgyavati
in"n"ane paRan~n~u:---``strIkaLOT sammataM cOdikkAte, avaruTe
ruciyuM, abhilASavuM, anurAgasthitiyuM aRiyAte, kaNakku vekkAte,
patimmUnnuM patinnAluM vayassuLLappOL, avareppiTicc, AjIvanAntaM
manasserin~n~u kazhiyuvAn{}vENTi, talaccORillAtta kazhutakaLuTekUTe
keTTiyiTTEkkunna sanpradAyaM niRttENTunna kAlaM atikramiccirikkunnu.
(hiyaR! hiyaR!---pi.ess.) enRe abhiprAyattil mElil
vivAhabandhattilERppeTuvAn uddEshikkunna vanitakaL
bhaR{}t.rsthAnARtthikaLilninnu harajikaL AvashyappeTENTatuM,
prAthamika selakSan kiTTiyavaruTe iTayilninn, `inTaRvyU'
kazhin~n~atinnushESaM, tan"n"aLkku paRRunna varanmAre
svIkarikkENTatumAN<<+.'' (hastaghOSavuM ciyEzhsuM)

I prasaMgattinnushESaM divasaM patinan~cu kazhin~n~appOzhEkkuM,
nammuTe saubhAgyavatiyuTe mEshappuRatt, nAnAsthalan"n"aLilninnuM
vanna ezhuttukaL, mahAmErupOle, kunniccukUTi. ellAM
avivAhitayAya saubhAgyavatiyuTe svayaMvarattinnu kAn"{}kSiccukoNTuLLa
bhaR{}t.rsthAnARtthikaLuTe apEkSAharajikaLAyirunnu ennu
paRayENTatillallO? EtAnuM harajikaLuTe pakaR{}ppukaL
tAzhe cER{}kkunnu.

\noindent oru DOkTaR in"n"ane ezhuti:

{\it
\noindent ArOgyavati,

bhavatiyuTe dEhattilninnu puRappeTTa rashmikaL kaN{}vazhiyAyi
enRe talaccORil ettiya uTane aviTe palE mARRan"n"aLuM
vannirikkunnu.

n~An nalla prAkRRIsuLLa oru DOkTaRAN<<+; arOgad.rDhagAtranAya
oru ceRuppakkAranumAN<<+. pakSE, bhavatiyekkaNTatumutal
OppaRESan kazhikkunpOL enRe kai viRaccutuTan"n"iyirikkunnu.
raNTumUnnu rOgikaL I EkakAraNattAl `koLApsA'yippOyi. bhavati
enne bhaRttAvAyi svIkariccillen"kil eniyuM anavadhipER
`koLApsA'yippOkuvAn iTayuNT. atu mAtramalla, maRRuLLavaruTe
nen~n~attu kuzhal{}vecc hARTTu parishOdhikkunna samayan"n"aLil
enRe svantaM nen~n~iTippinRe shabdaM enRe cevikaLil
``ghuM--ghuM'' ennu muzhan"n"ikkELkkunnatinnAl, avaRkkokke
h.rdayattinn entO tarakkETuNTennu n~An shan"kiccupOkunnu.
itinnupuRamE, bhavatiyekkuRiccuLLa cintahEtuvAyi enRe
AmAshayaM, pakvAshayaM, yak.rtt, plIha mutalAya anEkaM
AntarAvayavan"n"aL valiya takarARilAyirikkunnu. onnukil
bhavatiyuTe bhaR{}t.rpadaM; allen"kil dIRghakAlattEkku
nINTuninn oTukkaM maraNattil pariNamiccEkkAvunna krONik
DispepsiyayuM ekyUTT insOmniyayuM---ivayilonnAN<<+
n~An bhAviyilEkk tiran~n~eTukkENTivarika.
}

</m>
\begin{flushright}
<m>
{\it
enn,\\
AjIvanAntaM bhavatiyuTe,\\
........(eM.bi.bi.ess.)
}
</m>
\end{flushright}
<m>


\noindent oru vakkIl tAzhe cERkkuMprakAraM ezhuti:

{\it

1936 mey{}mAsaM 15--nu veLLiyAzhca pakal an~cumaNikkO, atinnaTuttO,
shrImati\mbox{.....}yAya nin"n"aL \mbox{.....}gaRaLs skULilO,
parisarattilO, vecc ceyta prasaMgattil, bhAviyil strIkaL
bhaRttAkkanmAre svIkarikkunnat bhaR{}t.rsthAnARtthikaLuTe
harajikaL prakAramAyirikkENamennO, A aRtthaM varunna maRRu
vAkkukaLO, paRan~n~irikkukayAluM, nin"n"aL avivAhitayANenn
enikk uttamavishvAsamuLLatinnAluM, mEppaTi sanpradAyattiluLLa
bhaR{}t.rsvIkaraNattinn nin"n"aL orukkamANenn mEppaTi
vAkkukaLilUTe dhvanikkunnatinAluM, I haraji ezhutunna n~An
avivAhitanAyatinAluM, I harajikku kAraNamAyittIRnnirikkunnu.

harajikkAranAya n~An ikkazhin~n~a 1936 Epril{}mAsaM
1--nu muppattan~cuvayassu tikaccirikkunna oru puruSanANennuM
(hindu, abrAhmaNan) itezhutunna samayattu n~An uzhalURDisTrikRR
kORTTil oru vakkIlANennuM pratimAsaM sivilAyuM kriminalAyuM uLLa
prAkRRIsukoNT enikku sharAshari varav 300ka. yANennuLLa
inkaMTAks OfIsaRuTe matippine n~An niSEdhikkAte, A
saMkhyakkuLLa tOtuprakAraM AdAyanikuti koTuttuvarunnuNTennuM,
taRavATTubhAgaM kazhiccatil, enikku kiTTiya kaTavuM
kOTaticcelavuM muzhuvan koTuttu tIRttatinnushESaM kiTTiya
Oharivila, kammISankaNakkuprakAraM 13ka. 8Na. 9pai.
mAtramANen"kiluM, enRe prAkRRIsukoNTuLLa varav Etu
strIyuTeyuM bhaR{}t.rpadavikk enne aRhanAkkittIR{}kkunnuNTennuM,
n~An itinAl nin"n"aLe aRiyiccukoLLunnu.

nin"n"aL enne bhaRttAvAyi svIkarikkunnapakSaM kOTatiyuLLa
oru divasaM kakSikaLilninnu fIsAyi kiTTunna paNattil
pakal samayatt kOTatiyil{}vaccuNTAyEkkAvunna nyAyamAya
celavukaL kazhicc bAkki saMkhya vITTil{}ttAmasamuLLa divasaM
rAtri pattumaNikkakattuM, kEssinnu puRamEpOyi tAmasikkENTivannAl
tiricc vITTiletti oru maNikkUR kazhiyunnatiliTaykkuM,
nin"n"aLuTe kaivashaM tannukoLLAmennuM, mun{}paRan~n~a
celavukaLuTe shariyAya oru kaNakkuM atOTukUTe
ElpiccukoLLAmennuM, kammISan fIsuLppeTe maRRuvazhikku
kiTTAvunna ellA varavukaL{}kkuM I nibandhana bAdhakamAkunnatANennuM,
nammaLil orAL marikkukayO, vivAhabandhaM vERppeTuttukayO
ceyyunnatuvare, n~An, kaTAkSaM, prEmalEkhanaM mutalAyava
vazhiyAyi maRRu yAtoru strIyuTEyuM nEre enikkuLLatO
uNTAkuvAniTayuLLatO Aya anurAgatte veLippeTuttunnatallennuM,
an"n"aneyoru vAgdAnaM nin"n"aL in"n"OTTuM tarENTatAyirikkumennuM
kUTi n~An nin"n"aLe itinAl aRiyiccukoLLunnu.

ennAl mARjanil\marginpar{\mm \footnotesize 1. ArOgyaM\\
2. saushIlaM\\ 3. saundaRyaM\\ 4. yauvanaM\\ 5. buddhi\\
6. taRavATittaM} vivariccirikkunna
nin"n"aLuTe ArOgyAdiguNan"n"aLeppaRRi vishvastarAya palE
sAkSikaLuM paRan~n~u n~An kEL{}kkukayuM onnAM
khaNDikayil paRayappeTTa bhaR{}t.rsvIkaraNatteppaRRiyuLLa
nin"n"aLuTe abhiprAyaM aRiyukayuM ceytatumutal enikkuLLa
anurAgaM hEtuvAyi kEssukaLilonnuM shraddha vENTatupOle
patiyAteyirikkunnuvennuM, atunimittaM enRe vaLare
vilapiTicca EtAnuM kakSikaLkk gaNyamAya naSTaM ippOLttanne
vannukazhin~n~irikkunnuvennuM kAlAntarattil I naSTaM enneyuM
bAdhikkuvAniTayuNTennuM, ikkARyattil nin"n"aLkk valla bAddhyatayumuNTenn
sivil{}niyamattil orETattuM kANAttatil n~An vyasanikkunnuvennuM,
pakSE, niyamasaMbandhamAya uttaravAditvamillen"kiluM,
itu nin"n"aLuTe kIRttikk oru uTavAyirikkumennuM nin"n"aLe
aRiyiykkENTunna cumatalayuM enikkuNT.

nin"n"aL enne svIkariykkAttapakSaM I kattayakkuvAn
ezhuttukUli uLppeTeyuLLa celavu 1ka. 1Na. 2pai. enikk
anAvashyamAya naSTamAyirikkumennu nin"n"aLe ORmmappeTuttunnu.

enn, vivAhaM kazhikkunnatuvareyO, maRRoru strIyil
anuraktanAkunnatuvareyO,

}
</m>
\begin{flushright}
<m>{\it
nin"n"aLuTe svantaM,\\
.....(bi.e. bi.el)
}
</m>
\end{flushright}
<m>

\dots

ini kavitUlikakaLuTe viLayATTan"n"aLkkAN<<+ n~An prAdhAnyaM
koTukkuvAn pOkunnat. AdyaM aran"n"ERunnat oru gadyakaviyuTe
prEmalEkhanamAN<<+. nOkkuvin.

{\it

``pARakkeTTilumuNT nIruRav; caTTukakkaLLikkumuNT pUv;
piNNAkkilumuNT mAdhuRyaM; karin"kARilumuNT tUminnal;
saRppashirassilumuNT mANikyamaNi; viplavakavitayilumuNT
nalla varikaL; rUkSanAya pUccayilumuNT saumyanAya eli;
ennilumuNT nI.

oru pon{}vINa oru karAMguliyuTe saprEmalALanatte pratIkSikkukayAN<<+;
cuTTeriyunna oru maruppaRanp svaRggIyamAya shItashIkaraspaRshatte
kAn"kSicc eriporikkoLLunna mAR{}viTatte nIlanabhassinnu
tuRannukATTukayAN<<+; oru grAmafON RikkARDile saMgItaM
sauN{}D bOksinRe sammELanaM kAtt kSamayillAte vaTTaM
cuRRukayAN<<+; oru pAzhman~n~in{}tuLLi tUmuttAyittIruvAn
aruNakiraNapravEshanattinnu nOnpunORRu n~AnnukiTakkukayAN<<+;---%
I seRRukaLil AdyattEtokke n~AnAN<<+, raNTAmattEtokke
nIyAN<<+.

atinRe pratyUSapavanan talOTiyappOLAN<<+ enRe pratyAshAmukuLaM
virin~n~at; atinRe kiraNakandaLan"n"aL cuMbiccappOLAN<<+
enRe nirAshAtamass ozhin~n~umARiyat; atinRe
kaLakOmaLakUjanattAlAN<<+ EkAntamAya enRe h.rdayattile
nishshabdatayilninnu mARRoli puRappeTTat; atinRe
koTun"kARRaTiccappOLAN<<+ enRe anyathAshan"kAshaSpan"n"aL
pARippOyat; `atu' ninRe prasaMgaM---ate, A divyavAgddhAra---%
Ayirunnu.

OmanE! enRe apEkSayAkunna I mazhattuLLi ninRe k.rpayAkunna A
muttuccippiyil{}ttanne pOyi vIzhukayillE? I himarashminipAtaM
A candrakAntatte aliyikkukayillE? I kallER<<+ A mAnpazhatte
tAzhE varuttukayillE?

hA, vINAl--aliyiccAl--varuttiyAl--bhUmi svaRggaM;
n~An dEvan; kOzhikkOT munisippAliRRi amarAvati; I kasAla
siMhAsanaM; piNNAkk jilEbi; maNNAn"kaTTa Rava laDu;
enRe pAcakan naLan; saR{}vvaM AnandaM, paramAnandaM.

ha, ha, vINillen"kil--alin~n~illen"kil--varuttiyillen"kil--%
bhUmi narakaM; n~An narakak.rmi; kAccikkuRukkiya pAl
kalaRppillAtta kAkOLaM; paninIr pInARi; pakal rAtri;
rAtri pakal; rAmAyaNaM rAvaNAyanaM; kastUri cANakaM;
ellAM abaddhaM, apakaTaM, aklImaM, nON{}sen{}s, kutiravaTTaM.

enn, anukUlamAya maRupaTiyuNTAkumennaRiyiccAl mAtraM
pEru paRayuvAn tIRccappeTuttiyirikkunna ninRe
caraNaikasharaNan.''
}

gadyakaviykk buddhi kaTukaTTiyANenn avasAnatte vAcakaM
teLiyikkunnuNTallO.

\dots

viSAdAtmakanmAruM veRuteyirunnilla. avaruTe iTayil{}ninnu
vanna aRunURilcilvAnaM harajikaLilninnu tAzhe cERkkunna
`OmanakkuTTa'vilApamAN<<+ saubhAgyavati tiran~n~eTuttayaccirikkunnat.
vAstavattil atu muzhuvan vAyiccutIRkkuvAn enikku
sAdhicciTTilla; pakuti vAyikkunpOzhEykkuM kaNNIrukoNT
n~An andhanAyippOyirikkunnu. iTattE kaiyil uRumAl
piTiccukoNTu mAtramE nin"n"aLitu vAyikkuvAn tuTan"n"AvU;
allen"kil kaNNunIR vINu san~jayanRe peyj vaSaLAvuM.
viSAdAtmakan in"n"ane mOn"n"i:

</m>
\begin{verse}
<m>
{\it
``khinnanAmenRe munnilAy shuddha--\\
shUnyata vA piLaRttunnU;\\
kANmatillonnumandhakArattAl:\\
kaNmizhi, hA! mE vyaRtthamAy;\\
OmanE, ninnekkAmikkuMmunpE--\\
yI maTTilANen kaNTISan</m>%
\footnote{Condition<m>--sthiti</m>};\\
<m>
AyatinshESamIyavasthaykku--\\
NTAya kAThinyaM bhIkaraM!\\
entinnAhAra?mentinnu veLLa?--\\
mentinnu kARRupOluM, hA?\\
entinnu mAna?mentinnu jIvan\\
bandhuraprEmaM pOrayO?\\
Accarakkinnu ninRe kaiyil{}ttAn\\
saccaritE, n~An kANunnu.\\
A vishuddhamAM prEmaM tIRttiTu--\\
mI viSAdAtmakatvatte.\\
nIyatu tannAl nAlunALattE--\\
kkIyivan pinnett.rptanAM!''
}</m>
\end{verse}
<m>

malayALasAhityattinRe dayanIyasthitiyORtt, atine I oru
viSAdAtmakanilninnen"kiluM rakSikkuvAnAyi, prastuta dEhaM
kaimalaRttiyirikkunna `nAlunALatte t.rpti' ayALkk
koTuttEykkuvAn pi.ess. saubhAgyavatiyOTabhyaRtthikkunnu.
atu saubhAgyavatiyuTe sOviyaRR AdaRshan"n"aLkk
viruddhavumallallO! kEraLattile ellA OmanakaLkkuM
an"n"ine cey{}vAnuLLa dayayuNTAyirunnen"kil I
AbhAsanmAruTe viSAdattinRe paicchilyaM
sAhityattilninnozhiyukayuM ceyyuM.

misRRikk kavikaLuTe harajikaLuM kuRe vanniTTuNT. onnitA:

</m>
\begin{verse}
<m>
``niRnnimESan"n"aLAy vAnil\\
rAkkaNNukaL viLan"n"avE,\\
candrOdayaM pratIkSiccu\\
vArAnnidhiyiranpavE,\\
puttancenpanIRppUvin\\
cuRRuM saMbhrAntacittanAy\\
oru vaNTu paRakkunnU\\
kUriruL{}cceNTupOlavE.\\
</m>
\end{verse}



\end{document}


